pub fn assert_own_book_consistent(cache: &Cache, instrument_id: &InstrumentId)Expand description
Asserts that every order retained in an own order book remains open in the cache.
pub fn assert_own_book_consistent(cache: &Cache, instrument_id: &InstrumentId)Asserts that every order retained in an own order book remains open in the cache.